pub struct AnywhereCachMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on anywhereCach resources.
It is not used directly, but through the Storage hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_storage1 as storage1;
use storage1::{Storage, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Storage::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `disable(...)`, `get(...)`, `insert(...)`, `list(...)`, `pause(...)`, `resume(...)` and `update(...)`
// to build up your call.
let rb = hub.anywhere_caches();Implementations
Sourceimpl<'a, C> AnywhereCachMethods<'a, C>
impl<'a, C> AnywhereCachMethods<'a, C>
Sourcepub fn disable(
&self,
bucket: &str,
anywhere_cache_id: &str,
) -> AnywhereCachDisableCall<'a, C>
pub fn disable( &self, bucket: &str, anywhere_cache_id: &str, ) -> AnywhereCachDisableCall<'a, C>
Create a builder to help you perform the following task:
Disables an Anywhere Cache instance.
Arguments
bucket- Name of the parent bucket.anywhereCacheId- The ID of requested Anywhere Cache instance.
Sourcepub fn get(
&self,
bucket: &str,
anywhere_cache_id: &str,
) -> AnywhereCachGetCall<'a, C>
pub fn get( &self, bucket: &str, anywhere_cache_id: &str, ) -> AnywhereCachGetCall<'a, C>
Create a builder to help you perform the following task:
Returns the metadata of an Anywhere Cache instance.
Arguments
bucket- Name of the parent bucket.anywhereCacheId- The ID of requested Anywhere Cache instance.
Sourcepub fn insert(
&self,
request: AnywhereCache,
bucket: &str,
) -> AnywhereCachInsertCall<'a, C>
pub fn insert( &self, request: AnywhereCache, bucket: &str, ) -> AnywhereCachInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates an Anywhere Cache instance.
Arguments
request- No description provided.bucket- Name of the parent bucket.
Sourcepub fn list(&self, bucket: &str) -> AnywhereCachListCall<'a, C>
pub fn list(&self, bucket: &str) -> AnywhereCachListCall<'a, C>
Create a builder to help you perform the following task:
Returns a list of Anywhere Cache instances of the bucket matching the criteria.
Arguments
bucket- Name of the parent bucket.
Sourcepub fn pause(
&self,
bucket: &str,
anywhere_cache_id: &str,
) -> AnywhereCachPauseCall<'a, C>
pub fn pause( &self, bucket: &str, anywhere_cache_id: &str, ) -> AnywhereCachPauseCall<'a, C>
Create a builder to help you perform the following task:
Pauses an Anywhere Cache instance.
Arguments
bucket- Name of the parent bucket.anywhereCacheId- The ID of requested Anywhere Cache instance.
Sourcepub fn resume(
&self,
bucket: &str,
anywhere_cache_id: &str,
) -> AnywhereCachResumeCall<'a, C>
pub fn resume( &self, bucket: &str, anywhere_cache_id: &str, ) -> AnywhereCachResumeCall<'a, C>
Create a builder to help you perform the following task:
Resumes a paused or disabled Anywhere Cache instance.
Arguments
bucket- Name of the parent bucket.anywhereCacheId- The ID of requested Anywhere Cache instance.
Sourcepub fn update(
&self,
request: AnywhereCache,
bucket: &str,
anywhere_cache_id: &str,
) -> AnywhereCachUpdateCall<'a, C>
pub fn update( &self, request: AnywhereCache, bucket: &str, anywhere_cache_id: &str, ) -> AnywhereCachUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates the config(ttl and admissionPolicy) of an Anywhere Cache instance.
Arguments
request- No description provided.bucket- Name of the parent bucket.anywhereCacheId- The ID of requested Anywhere Cache instance.