pub struct FolderMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on folder resources.
It is not used directly, but through the Storage hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_storage1 as storage1;
use storage1::{Storage, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Storage::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)` and `rename(...)`
// to build up your call.
let rb = hub.folders();Implementations
Sourceimpl<'a, C> FolderMethods<'a, C>
impl<'a, C> FolderMethods<'a, C>
Sourcepub fn delete(&self, bucket: &str, folder: &str) -> FolderDeleteCall<'a, C>
pub fn delete(&self, bucket: &str, folder: &str) -> FolderDeleteCall<'a, C>
Create a builder to help you perform the following task:
Permanently deletes a folder. Only applicable to buckets with hierarchical namespace enabled.
Arguments
bucket- Name of the bucket in which the folder resides.folder- Name of a folder.
Sourcepub fn get(&self, bucket: &str, folder: &str) -> FolderGetCall<'a, C>
pub fn get(&self, bucket: &str, folder: &str) -> FolderGetCall<'a, C>
Create a builder to help you perform the following task:
Returns metadata for the specified folder. Only applicable to buckets with hierarchical namespace enabled.
Arguments
bucket- Name of the bucket in which the folder resides.folder- Name of a folder.
Sourcepub fn insert(&self, request: Folder, bucket: &str) -> FolderInsertCall<'a, C>
pub fn insert(&self, request: Folder, bucket: &str) -> FolderInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a new folder. Only applicable to buckets with hierarchical namespace enabled.
Arguments
request- No description provided.bucket- Name of the bucket in which the folder resides.
Sourcepub fn list(&self, bucket: &str) -> FolderListCall<'a, C>
pub fn list(&self, bucket: &str) -> FolderListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of folders matching the criteria. Only applicable to buckets with hierarchical namespace enabled.
Arguments
bucket- Name of the bucket in which to look for folders.
Sourcepub fn rename(
&self,
bucket: &str,
source_folder: &str,
destination_folder: &str,
) -> FolderRenameCall<'a, C>
pub fn rename( &self, bucket: &str, source_folder: &str, destination_folder: &str, ) -> FolderRenameCall<'a, C>
Create a builder to help you perform the following task:
Renames a source folder to a destination folder. Only applicable to buckets with hierarchical namespace enabled.
Arguments
bucket- Name of the bucket in which the folders are in.sourceFolder- Name of the source folder.destinationFolder- Name of the destination folder.