Struct google_storage1::api::ObjectAccessControls[][src]

pub struct ObjectAccessControls {
    pub items: Option<Vec<ObjectAccessControl>>,
    pub kind: Option<String>,
}

An access-control list.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

items: Option<Vec<ObjectAccessControl>>

The list of items.

kind: Option<String>

The kind of item this is. For lists of object access control entries, this is always storage#objectAccessControls.