Struct google_storage1::BucketLifecycle

source ·
pub struct BucketLifecycle {
    pub rule: Option<Vec<BucketLifecycleRule>>,
}
The bucket’s lifecycle configuration. See lifecycle management for more information.

This type is not used in any activity, and only used as part of another schema.

Fields

rule: Option<Vec<BucketLifecycleRule>>

A lifecycle management rule, which is made of an action to take and the condition(s) under which the action will be taken.