pub struct BucketLifecycleRuleCondition {
pub is_live: Option<bool>,
pub matches_storage_class: Option<Vec<String>>,
pub age: Option<i32>,
pub num_newer_versions: Option<i32>,
pub created_before: Option<String>,
}Expand description
The condition(s) under which the action will be taken.
This type is not used in any activity, and only used as part of another schema.
Fields
is_live: Option<bool>Relevant only for versioned objects. If the value is true, this condition matches live objects; if the value is false, it matches archived objects.
matches_storage_class: Option<Vec<String>>Objects having any of the storage classes specified by this condition will be matched. Values include MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, STANDARD, and DURABLE_REDUCED_AVAILABILITY.
age: Option<i32>Age of an object (in days). This condition is satisfied when an object reaches the specified age.
num_newer_versions: Option<i32>Relevant only for versioned objects. If the value is N, this condition is satisfied when there are at least N versions (including the live version) newer than this version of the object.
created_before: Option<String>A date in RFC 3339 format with only the date part (for instance, “2013-01-15”). This condition is satisfied when an object is created before midnight of the specified date in UTC.