Struct google_storage1::BucketVersioning
[−]
[src]
pub struct BucketVersioning {
pub enabled: Option<bool>,
}The bucket's versioning configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>
While set to true, versioning is fully enabled for this bucket.