[−][src]Struct google_storage1::HmacKey
JSON template to produce a JSON-style HMAC Key resource for Create responses.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- hmac keys create projects (response)
Fields
kind: Option<String>The kind of item this is. For HMAC keys, this is always storage#hmacKey.
secret: Option<String>HMAC secret key material.
metadata: Option<HmacKeyMetadata>Key metadata.