[−][src]Struct google_storage1::HmacKeyMetadata
JSON template to produce a JSON-style HMAC Key metadata resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- hmac keys update projects (request|response)
- hmac keys get projects (response)
Fields
kind: Option<String>The kind of item this is. For HMAC Key metadata, this is always storage#hmacKeyMetadata.
time_created: Option<String>The creation time of the HMAC key in RFC 3339 format.
project_id: Option<String>Project ID owning the service account to which the key authenticates.
updated: Option<String>The last modification time of the HMAC key metadata in RFC 3339 format.
access_id: Option<String>The ID of the HMAC Key.
state: Option<String>The state of the key. Can be one of ACTIVE, INACTIVE, or DELETED.
etag: Option<String>HTTP 1.1 Entity tag for the HMAC key.
service_account_email: Option<String>The email address of the key's associated service account.
id: Option<String>The ID of the HMAC key, including the Project ID and the Access ID.
self_link: Option<String>The link to this resource.