Struct google_storage1::ObjectComposeCall
source · pub struct ObjectComposeCall<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
Concatenates a list of existing objects into a new object in the same bucket.
This method supports media download. To enable it, adjust the builder like this:
.param("alt", "media").
Please note that due to missing multi-part support on the server side, you will only receive the media,
but not the Object structure that you would usually get. The latter will be a default value.
A builder for the compose method supported by a object resource.
It is not used directly, but through a ObjectMethods instance.
Example
Instantiate a resource method builder
use storage1::ComposeRequest;
// As the method needs a request, you would usually fill it with the desired information
// into the respective structure. Some of the parts shown here might not be applicable !
// Values shown here are possibly random and not representative !
let mut req = ComposeRequest::default();
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.objects().compose(req, "destinationBucket", "destinationObject")
.user_project("ut")
.if_metageneration_match("amet.")
.if_generation_match("ipsum")
.destination_predefined_acl("ut")
.doit();Implementations
sourceimpl<'a, C, A> ObjectComposeCall<'a, C, A>
impl<'a, C, A> ObjectComposeCall<'a, C, A>
sourcepub fn request(self, new_value: ComposeRequest) -> ObjectComposeCall<'a, C, A>
pub fn request(self, new_value: ComposeRequest) -> ObjectComposeCall<'a, C, A>
Sets the request property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
sourcepub fn destination_bucket(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
pub fn destination_bucket(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
Name of the bucket in which to store the new object.
Sets the destination bucket path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
sourcepub fn destination_object(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
pub fn destination_object(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
Name of the new object. For information about how to URL encode object names to be path safe, see Encoding URI Path Parts.
Sets the destination object path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
sourcepub fn user_project(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
pub fn user_project(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
The project number to be billed for this request, for Requester Pays buckets.
Sets the user project query property to the given value.
sourcepub fn if_metageneration_match(
self,
new_value: &str,
) -> ObjectComposeCall<'a, C, A>
pub fn if_metageneration_match( self, new_value: &str, ) -> ObjectComposeCall<'a, C, A>
Makes the operation conditional on whether the object’s current metageneration matches the given value.
Sets the if metageneration match query property to the given value.
sourcepub fn if_generation_match(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
pub fn if_generation_match(self, new_value: &str) -> ObjectComposeCall<'a, C, A>
Makes the operation conditional on whether the object’s current generation matches the given value.
Sets the if generation match query property to the given value.
sourcepub fn destination_predefined_acl(
self,
new_value: &str,
) -> ObjectComposeCall<'a, C, A>
pub fn destination_predefined_acl( self, new_value: &str, ) -> ObjectComposeCall<'a, C, A>
Apply a predefined set of access controls to the destination object.
Sets the destination predefined acl query property to the given value.
sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> ObjectComposeCall<'a, C, A>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> ObjectComposeCall<'a, C, A>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
sourcepub fn param<T>(self, name: T, value: T) -> ObjectComposeCall<'a, C, A>
pub fn param<T>(self, name: T, value: T) -> ObjectComposeCall<'a, C, A>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known paramters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- userIp (query-string) - IP address of the site where the request originates. Use this if you want to enforce per-user limits.
- fields (query-string) - Selector specifying which fields to include in a partial response.
- alt (query-string) - Data format for the response.
sourcepub fn add_scope<T>(self, scope: T) -> ObjectComposeCall<'a, C, A>
pub fn add_scope<T>(self, scope: T) -> ObjectComposeCall<'a, C, A>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead the default Scope variant
Scope::CloudPlatform.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.