Struct google_storage1::ObjectCustomerEncryption [−][src]
pub struct ObjectCustomerEncryption {
pub encryption_algorithm: Option<String>,
pub key_sha256: Option<String>,
}Metadata of customer-supplied encryption key, if the object is encrypted by such a key.
This type is not used in any activity, and only used as part of another schema.
Fields
encryption_algorithm: Option<String>
The encryption algorithm.
key_sha256: Option<String>
SHA256 hash value of the encryption key.