[−][src]Struct google_storage1::ObjectOwner
The owner of the object. This will always be the uploader of the object.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_id: Option<String>The ID for the entity.
entity: Option<String>The entity, in the form user-userId.