Trait google_storage1::NestedType
[−]
[src]
pub trait NestedType { }Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.
Implementors
impl NestedType for BucketLifecycleRuleimpl NestedType for ObjectAccessControlProjectTeamimpl NestedType for BucketLifecycleRuleConditionimpl NestedType for BucketWebsiteimpl NestedType for BucketLoggingimpl NestedType for BucketLifecycleimpl NestedType for BucketVersioningimpl NestedType for BucketCorsimpl NestedType for BucketAccessControlProjectTeamimpl NestedType for ComposeRequestSourceObjectsObjectPreconditionsimpl NestedType for ComposeRequestSourceObjectsimpl NestedType for ObjectCustomerEncryptionimpl NestedType for ObjectOwnerimpl NestedType for BucketLifecycleRuleActionimpl NestedType for BucketOwner