pub struct BucketEncryption {
pub customer_managed_encryption_enforcement_config: Option<BucketEncryptionCustomerManagedEncryptionEnforcementConfig>,
pub customer_supplied_encryption_enforcement_config: Option<BucketEncryptionCustomerSuppliedEncryptionEnforcementConfig>,
pub default_kms_key_name: Option<String>,
pub google_managed_encryption_enforcement_config: Option<BucketEncryptionGoogleManagedEncryptionEnforcementConfig>,
}Expand description
Encryption configuration for a bucket.
This type is not used in any activity, and only used as part of another schema.
Fields
customer_managed_encryption_enforcement_config: Option<BucketEncryptionCustomerManagedEncryptionEnforcementConfig>If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Customer Managed Encryption type by default.
customer_supplied_encryption_enforcement_config: Option<BucketEncryptionCustomerSuppliedEncryptionEnforcementConfig>If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Customer Supplied Encryption type by default.
default_kms_key_name: Option<String>A Cloud KMS key that will be used to encrypt objects inserted into this bucket, if no encryption method is specified.
google_managed_encryption_enforcement_config: Option<BucketEncryptionGoogleManagedEncryptionEnforcementConfig>If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Google Managed Encryption type by default.