pub struct BucketEncryptionGoogleManagedEncryptionEnforcementConfig {
pub effective_time: Option<DateTime<Utc>>,
pub restriction_mode: Option<String>,
}Expand description
If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Google Managed Encryption type by default.
This type is not used in any activity, and only used as part of another schema.
Fields
effective_time: Option<DateTime<Utc>>Server-determined value that indicates the time from which configuration was enforced and effective. This value is in RFC 3339 format.
restriction_mode: Option<String>Restriction mode for Google-Managed Encryption Keys. Defaults to NotRestricted.