pub struct BucketMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on bucket resources.
It is not used directly, but through the Storage hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_storage1 as storage1;
use storage1::{Storage, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Storage::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `get_iam_policy(...)`, `get_storage_layout(...)`, `insert(...)`, `list(...)`, `lock_retention_policy(...)`, `operations_advance_relocate_bucket(...)`, `operations_cancel(...)`, `operations_get(...)`, `operations_list(...)`, `patch(...)`, `relocate(...)`, `restore(...)`, `set_iam_policy(...)`, `test_iam_permissions(...)` and `update(...)`
// to build up your call.
let rb = hub.buckets();Implementations
Sourceimpl<'a, C> BucketMethods<'a, C>
impl<'a, C> BucketMethods<'a, C>
Sourcepub fn delete(&self, bucket: &str) -> BucketDeleteCall<'a, C>
pub fn delete(&self, bucket: &str) -> BucketDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes an empty bucket. Deletions are permanent unless soft delete is enabled on the bucket.
Arguments
bucket- Name of a bucket.
Sourcepub fn get(&self, bucket: &str) -> BucketGetCall<'a, C>
pub fn get(&self, bucket: &str) -> BucketGetCall<'a, C>
Create a builder to help you perform the following task:
Returns metadata for the specified bucket.
Arguments
bucket- Name of a bucket.
Sourcepub fn get_iam_policy(&self, bucket: &str) -> BucketGetIamPolicyCall<'a, C>
pub fn get_iam_policy(&self, bucket: &str) -> BucketGetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Returns an IAM policy for the specified bucket.
Arguments
bucket- Name of a bucket.
Sourcepub fn get_storage_layout(
&self,
bucket: &str,
) -> BucketGetStorageLayoutCall<'a, C>
pub fn get_storage_layout( &self, bucket: &str, ) -> BucketGetStorageLayoutCall<'a, C>
Create a builder to help you perform the following task:
Returns the storage layout configuration for the specified bucket. Note that this operation requires storage.objects.list permission.
Arguments
bucket- Name of a bucket.
Sourcepub fn insert(&self, request: Bucket, project: &str) -> BucketInsertCall<'a, C>
pub fn insert(&self, request: Bucket, project: &str) -> BucketInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a new bucket.
Arguments
request- No description provided.project- A valid API project identifier.
Sourcepub fn list(&self, project: &str) -> BucketListCall<'a, C>
pub fn list(&self, project: &str) -> BucketListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of buckets for a given project.
Arguments
project- A valid API project identifier.
Sourcepub fn lock_retention_policy(
&self,
bucket: &str,
if_metageneration_match: i64,
) -> BucketLockRetentionPolicyCall<'a, C>
pub fn lock_retention_policy( &self, bucket: &str, if_metageneration_match: i64, ) -> BucketLockRetentionPolicyCall<'a, C>
Create a builder to help you perform the following task:
Locks retention policy on a bucket.
Arguments
bucket- Name of a bucket.ifMetagenerationMatch- Makes the operation conditional on whether bucket’s current metageneration matches the given value.
Sourcepub fn patch(&self, request: Bucket, bucket: &str) -> BucketPatchCall<'a, C>
pub fn patch(&self, request: Bucket, bucket: &str) -> BucketPatchCall<'a, C>
Create a builder to help you perform the following task:
Patches a bucket. Changes to the bucket will be readable immediately after writing, but configuration changes may take time to propagate.
Arguments
request- No description provided.bucket- Name of a bucket.
Sourcepub fn relocate(
&self,
request: RelocateBucketRequest,
bucket: &str,
) -> BucketRelocateCall<'a, C>
pub fn relocate( &self, request: RelocateBucketRequest, bucket: &str, ) -> BucketRelocateCall<'a, C>
Create a builder to help you perform the following task:
Initiates a long-running Relocate Bucket operation on the specified bucket.
Arguments
request- No description provided.bucket- Name of the bucket to be moved.
Sourcepub fn restore(&self, bucket: &str, generation: i64) -> BucketRestoreCall<'a, C>
pub fn restore(&self, bucket: &str, generation: i64) -> BucketRestoreCall<'a, C>
Create a builder to help you perform the following task:
Restores a soft-deleted bucket.
Arguments
bucket- Name of a bucket.generation- Generation of a bucket.
Sourcepub fn set_iam_policy(
&self,
request: Policy,
bucket: &str,
) -> BucketSetIamPolicyCall<'a, C>
pub fn set_iam_policy( &self, request: Policy, bucket: &str, ) -> BucketSetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Updates an IAM policy for the specified bucket.
Arguments
request- No description provided.bucket- Name of a bucket.
Sourcepub fn test_iam_permissions(
&self,
bucket: &str,
permissions: &Vec<String>,
) -> BucketTestIamPermissionCall<'a, C>
pub fn test_iam_permissions( &self, bucket: &str, permissions: &Vec<String>, ) -> BucketTestIamPermissionCall<'a, C>
Create a builder to help you perform the following task:
Tests a set of permissions on the given bucket to see which, if any, are held by the caller.
Arguments
bucket- Name of a bucket.permissions- Permissions to test.
Sourcepub fn update(&self, request: Bucket, bucket: &str) -> BucketUpdateCall<'a, C>
pub fn update(&self, request: Bucket, bucket: &str) -> BucketUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates a bucket. Changes to the bucket will be readable immediately after writing, but configuration changes may take time to propagate.
Arguments
request- No description provided.bucket- Name of a bucket.
Sourcepub fn operations_advance_relocate_bucket(
&self,
request: AdvanceRelocateBucketOperationRequest,
bucket: &str,
operation_id: &str,
) -> BucketOperationAdvanceRelocateBucketCall<'a, C>
pub fn operations_advance_relocate_bucket( &self, request: AdvanceRelocateBucketOperationRequest, bucket: &str, operation_id: &str, ) -> BucketOperationAdvanceRelocateBucketCall<'a, C>
Create a builder to help you perform the following task:
Starts asynchronous advancement of the relocate bucket operation in the case of required write downtime, to allow it to lock the bucket at the source location, and proceed with the bucket location swap. The server makes a best effort to advance the relocate bucket operation, but success is not guaranteed.
Arguments
request- No description provided.bucket- Name of the bucket to advance the relocate for.operationId- ID of the operation resource.
Sourcepub fn operations_cancel(
&self,
bucket: &str,
operation_id: &str,
) -> BucketOperationCancelCall<'a, C>
pub fn operations_cancel( &self, bucket: &str, operation_id: &str, ) -> BucketOperationCancelCall<'a, C>
Create a builder to help you perform the following task:
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed.
Arguments
bucket- The parent bucket of the operation resource.operationId- The ID of the operation resource.
Sourcepub fn operations_get(
&self,
bucket: &str,
operation_id: &str,
) -> BucketOperationGetCall<'a, C>
pub fn operations_get( &self, bucket: &str, operation_id: &str, ) -> BucketOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation.
Arguments
bucket- The parent bucket of the operation resource.operationId- The ID of the operation resource.
Sourcepub fn operations_list(&self, bucket: &str) -> BucketOperationListCall<'a, C>
pub fn operations_list(&self, bucket: &str) -> BucketOperationListCall<'a, C>
Create a builder to help you perform the following task:
Lists operations that match the specified filter in the request.
Arguments
bucket- Name of the bucket in which to look for operations.