pub struct BucketLifecycleRuleAction {
pub type_: Option<String>,
pub storage_class: Option<String>,
}Expand description
The action to take.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>Type of the action. Currently, only Delete and SetStorageClass are supported.
storage_class: Option<String>Target storage class. Required iff the type of the action is SetStorageClass.