pub struct BucketLifecycleRuleCondition {
pub num_newer_versions: Option<i32>,
pub created_before: Option<String>,
pub matches_pattern: Option<String>,
pub is_live: Option<bool>,
pub matches_storage_class: Option<Vec<String>>,
pub age: Option<i32>,
}Expand description
The condition(s) under which the action will be taken.
This type is not used in any activity, and only used as part of another schema.
Fields
num_newer_versions: Option<i32>Relevant only for versioned objects. If the value is N, this condition is satisfied when there are at least N versions (including the live version) newer than this version of the object.
created_before: Option<String>A date in RFC 3339 format with only the date part (for instance, “2013-01-15”). This condition is satisfied when an object is created before midnight of the specified date in UTC.
matches_pattern: Option<String>A regular expression that satisfies the RE2 syntax. This condition is satisfied when the name of the object matches the RE2 pattern. Note: This feature is currently in the “Early Access” launch stage and is only available to a whitelisted set of users; that means that this feature may be changed in backward-incompatible ways and that it is not guaranteed to be released.
is_live: Option<bool>Relevant only for versioned objects. If the value is true, this condition matches live objects; if the value is false, it matches archived objects.
matches_storage_class: Option<Vec<String>>Objects having any of the storage classes specified by this condition will be matched. Values include MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, STANDARD, and DURABLE_REDUCED_AVAILABILITY.
age: Option<i32>Age of an object (in days). This condition is satisfied when an object reaches the specified age.