Trait google_storage1::NestedType
[−]
[src]
pub trait NestedType { }Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.
Implementors
impl NestedType for BucketLifecycleRuleActionimpl NestedType for ComposeRequestSourceObjectsObjectPreconditionsimpl NestedType for ComposeRequestSourceObjectsimpl NestedType for BucketCorsimpl NestedType for BucketLifecycleRuleimpl NestedType for ObjectCustomerEncryptionimpl NestedType for ObjectAccessControlProjectTeamimpl NestedType for BucketLifecycleRuleConditionimpl NestedType for PolicyBindingsimpl NestedType for BucketLoggingimpl NestedType for BucketLifecycleimpl NestedType for BucketWebsiteimpl NestedType for ObjectOwnerimpl NestedType for BucketOwnerimpl NestedType for BucketBillingimpl NestedType for BucketAccessControlProjectTeamimpl NestedType for BucketVersioning