google_storage11.0.7+20180905

NestedType

Implementors

In crate google_storage1

Trait google_storage1::NestedType

source ·
pub trait NestedType { }
Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.

Implementors

source

impl NestedType for BucketAccessControlProjectTeam

source

impl NestedType for BucketBilling

source

impl NestedType for BucketCors

source

impl NestedType for BucketEncryption

source

impl NestedType for BucketLifecycle

source

impl NestedType for BucketLifecycleRule

source

impl NestedType for BucketLifecycleRuleAction

source

impl NestedType for BucketLifecycleRuleCondition

source

impl NestedType for BucketLogging

source

impl NestedType for BucketOwner

source

impl NestedType for BucketRetentionPolicy

source

impl NestedType for BucketVersioning

source

impl NestedType for BucketWebsite

source

impl NestedType for ComposeRequestSourceObjects

source

impl NestedType for ComposeRequestSourceObjectsObjectPreconditions

source

impl NestedType for ObjectAccessControlProjectTeam

source

impl NestedType for ObjectCustomerEncryption

source

impl NestedType for ObjectOwner

source

impl NestedType for PolicyBindings